@@ -10,11 +10,12 @@ An easy to use HTTP client based on httplib.
 :license: BSD 2-clause License, see LICENSE for more details.
 """
 
-__version__ = "2.0.0"
+__version__ = "2.0.1"
 __author__ = "Yue Du <ifduyue@gmail.com>"
 __url__ = "https://github.com/ifduyue/urlfetch"
 __license__ = "BSD 2-Clause License"
 
+import zlib
 import os, sys, base64, codecs, uuid, stat, time, socket
 import ssl
 from os.path import basename, dirname, abspath, join as pathjoin
@@ -28,8 +29,7 @@ except ImportError:
     import json
 
 from http.client import HTTPConnection, HTTPSConnection
-from urllib.parse import urlencode
-import urllib.parse as urlparse
+from urllib.parse import parse_qs, urlencode, urlsplit, urljoin
 import http.cookies as Cookie
 
 basestring = (str, bytes)
@@ -224,7 +224,7 @@ class Response(object):
         self._decoder = None
 
         try:
-            self.length_limit = int(kwargs.get("length_limit"))
+            self.length_limit = int(kwargs.get("length_limit", 0)) or None
         except:
             self.length_limit = None
 
@@ -259,8 +259,6 @@ class Response(object):
             ce = self._content_encoding
             if ce in ("gzip", "deflate"):
                 if not self._decoder:
-                    import zlib
-
                     if ce == "gzip":
                         self._decoder = zlib.decompressobj(16 + zlib.MAX_WBITS)
                     else:
@@ -667,6 +665,8 @@ def request(
     scheme = parsed_url["scheme"]
     if proxies is None and trust_env:
         proxies = PROXIES
+    if not proxies:
+        proxies = {}
 
     ignore_hosts = PROXY_IGNORE_HOSTS
     if trust_env:
@@ -755,7 +755,7 @@ def request(
         if location[:2] == "//":
             url = parsed_url["scheme"] + ":" + location
         else:
-            url = urlparse.urljoin(url, location)
+            url = urljoin(url, location)
         parsed_url = parse_url(url)
 
         reqheaders["Host"] = parsed_url["http_host"]
@@ -867,7 +867,7 @@ def parse_url(url):
     else:
         scheme = "http"
     url = "http://" + url
-    parsed = urlparse.urlsplit(url)
+    parsed = urlsplit(url)
     r = ObjectDict()
     r["scheme"] = scheme
     r["netloc"] = parsed.netloc
@@ -994,12 +994,12 @@ def url_concat(url, args, keep_existing=True):
     if keep_existing:
         if url[-1] not in ("?", "&"):
             url += "&" if ("?" in url) else "?"
-        return url + urlencode(args, 1)
+        return url + urlencode(args, True)
     else:
         url, seq, query = url.partition("?")
-        query = urlparse.parse_qs(query, True)
+        query = parse_qs(query, True)
         query.update(args)
-        return url + "?" + urlencode(query, 1)
+        return url + "?" + urlencode(query, True)
 
 
 def choose_boundary():
@@ -1081,7 +1081,7 @@ def encode_multipart(data, files):
             body.write(b"Content-Type: application/octet-stream\r\n\r\n")
         else:
             writer(body).write(
-                'Content-Disposition: form-data; name="%s"' "\r\n" % name
+                'Content-Disposition: form-data; name="%s"' "\r\n" % fieldname
             )
             body.write(b"Content-Type: text/plain\r\n\r\n")
 
